==> webkit2gtk_2.47.4.orig.tar.xz: webkitgtk-2.47.4/Source/WebKit/UIProcess/WebColorPicker.h <==
/*
 * Copyright (C) 2012 Intel Corporation. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <wtf/CheckedPtr.h>
#include <wtf/Ref.h>
#include <wtf/RefCounted.h>

namespace WebCore {
class Color;
}

namespace WebKit {

class WebPageProxy;

class WebColorPickerClient : public CanMakeCheckedPtr<WebColorPickerClient> {
    WTF_MAKE_FAST_ALLOCATED;
    WTF_OVERRIDE_DELETE_FOR_CHECKED_PTR(WebColorPickerClient);
public:
    virtual void didChooseColor(const WebCore::Color&) = 0;
    virtual void didEndColorPicker() = 0;

protected:
    virtual ~WebColorPickerClient() = default;
};

class WebColorPicker : public RefCounted<WebColorPicker> {
public:
    using Client = WebColorPickerClient;

    static Ref<WebColorPicker> create(Client* client)
    {
        return adoptRef(*new WebColorPicker(client));
    }

    virtual ~WebColorPicker();

    virtual void endPicker();
    virtual void setSelectedColor(const WebCore::Color&);
    virtual void showColorPicker(const WebCore::Color&);

protected:
    explicit WebColorPicker(Client*);

    Client* client() const { return m_client.get(); }

private:
    CheckedPtr<Client> m_client;
};

} // namespace WebKit

==> webkit2gtk_2.48.1.orig.tar.xz: webkitgtk-2.48.1/Source/WebKit/UIProcess/WebColorPicker.h <==
/*
 * Copyright (C) 2012 Intel Corporation. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <wtf/CheckedPtr.h>
#include <wtf/Ref.h>
#include <wtf/RefCountedAndCanMakeWeakPtr.h>

namespace WebCore {
class Color;
}

namespace WebKit {

class WebPageProxy;

class WebColorPickerClient : public CanMakeCheckedPtr<WebColorPickerClient> {
    WTF_MAKE_FAST_ALLOCATED;
    WTF_OVERRIDE_DELETE_FOR_CHECKED_PTR(WebColorPickerClient);
public:
    virtual void didChooseColor(const WebCore::Color&) = 0;
    virtual void didEndColorPicker() = 0;

protected:
    virtual ~WebColorPickerClient() = default;
};

class WebColorPicker : public RefCountedAndCanMakeWeakPtr<WebColorPicker> {
public:
    using Client = WebColorPickerClient;

    static Ref<WebColorPicker> create(Client* client)
    {
        return adoptRef(*new WebColorPicker(client));
    }

    virtual ~WebColorPicker();

    virtual void endPicker();
    virtual void setSelectedColor(const WebCore::Color&);
    virtual void showColorPicker(const WebCore::Color&);

protected:
    explicit WebColorPicker(Client*);

    Client* client() const { return m_client.get(); }

private:
    CheckedPtr<Client> m_client;
};

} // namespace WebKit
